@@ -8,36 +8,49 @@ use lindera_core::character_definition::CharacterDefinitions;
 use lindera_core::connection::ConnectionCostMatrix;
 use lindera_core::dictionary_builder::DictionaryBuilder;
 use lindera_core::error::LinderaErrorKind;
+use lindera_core::file_util::read_file;
 use lindera_core::prefix_dict::PrefixDict;
 use lindera_core::unknown_dictionary::UnknownDictionary;
+use lindera_core::user_dictionary::UserDictionary;
 use lindera_core::viterbi::{Lattice, Mode};
 use lindera_core::word_entry::WordId;
 use lindera_core::LinderaResult;
 use lindera_ipadic_builder::ipadic_builder::IpadicBuilder;
 
 #[derive(Serialize, Clone)]
+/// Token Object
 pub struct Token<'a> {
     pub text: &'a str,
     pub detail: Vec<String>,
 }
 
+/// Tokenizer config
 pub struct TokenizerConfig<'a> {
+    /// the path of System Dictionary
     pub dict_path: Option<&'a Path>,
+    /// the path of User Dictionary (CSV)
     pub user_dict_path: Option<&'a Path>,
+    /// the path of User Dictionary (Binary)
+    pub user_dict_bin_path: Option<&'a Path>,
+    /// Tokenize mode
     pub mode: Mode,
 }
 
 impl Default for TokenizerConfig<'_> {
+    /// Return default Tokenizer config
+    /// default mode is Mode::Normal
     fn default() -> Self {
         Self {
             dict_path: None,
             user_dict_path: None,
+            user_dict_bin_path: None,
             mode: Mode::Normal,
         }
     }
 }
 
 #[derive(Clone)]
+/// Tokenizer
 pub struct Tokenizer {
     dict: PrefixDict<Vec<u8>>,
     cost_matrix: ConnectionCostMatrix,
@@ -53,11 +66,20 @@ pub struct Tokenizer {
 }
 
 impl Tokenizer {
+    /// Creates a new instance with default TokenizerConfig
     pub fn new() -> LinderaResult<Tokenizer> {
         let config = TokenizerConfig::default();
         Tokenizer::with_config(config)
     }
 
+    /// Creates a new instance with the config
+    ///
+    /// # Arguments
+    ///
+    /// * `config`: settings of Tokenizer
+    ///
+    /// returns: Result<Tokenizer, LinderaError>
+    ///
     pub fn with_config(config: TokenizerConfig) -> LinderaResult<Tokenizer> {
         let dict = if let Some(ref path) = config.dict_path {
             lindera_dictionary::prefix_dict(path)?
@@ -104,6 +126,14 @@ impl Tokenizer {
                     Some(user_dict.words_idx_data),
                     Some(user_dict.words_data),
                 )
+            } else if let Some(path) = config.user_dict_bin_path {
+                let user_dict_bin_data = read_file(path)?;
+                let user_dict = UserDictionary::load(&user_dict_bin_data)?;
+                (
+                    Some(user_dict.dict),
+                    Some(user_dict.words_idx_data),
+                    Some(user_dict.words_data),
+                )
             } else {
                 (None, None, None)
             };
@@ -209,6 +239,17 @@ impl Tokenizer {
         Ok(word_detail)
     }
 
+    /// Tokenize the text
+    ///
+    /// # Arguments
+    ///
+    /// * `text`: Japanese text
+    ///
+    /// returns: Result<Vec<Token>, LinderaError>
+    ///
+    /// * Vec<Token> : the list of `Token` if succeeded
+    /// * LinderaError : Error message with LinderaErrorKind
+    ///
     pub fn tokenize<'a>(&mut self, mut text: &'a str) -> LinderaResult<Vec<Token<'a>>> {
         let mut tokens = Vec::new();
         while let Some(split_idx) = text.find(|c| c == '。' || c == '、') {
@@ -222,6 +263,17 @@ impl Tokenizer {
         Ok(tokens)
     }
 
+    /// Tokenize the text
+    ///
+    /// # Arguments
+    ///
+    /// * `text`: Japanese text
+    ///
+    /// returns: Result<Vec<&str>, LinderaError>
+    ///
+    /// * Vec<Token> : the list of `words` if succeeded
+    /// * LinderaError : Error message with LinderaErrorKind
+    ///
     pub fn tokenize_str<'a>(&mut self, text: &'a str) -> LinderaResult<Vec<&'a str>> {
         let tokens = self
             .tokenize(text)?
@@ -247,9 +299,8 @@ mod tests {
     #[test]
     fn test_empty() {
         let config = TokenizerConfig {
-            dict_path: None,
-            user_dict_path: None,
             mode: Mode::Decompose(Penalty::default()),
+            ..TokenizerConfig::default()
         };
         let mut tokenizer = Tokenizer::with_config(config).unwrap();
         let tokens = tokenizer.tokenize_offsets("");
@@ -259,9 +310,8 @@ mod tests {
     #[test]
     fn test_space() {
         let config = TokenizerConfig {
-            dict_path: None,
-            user_dict_path: None,
             mode: Mode::Decompose(Penalty::default()),
+            ..TokenizerConfig::default()
         };
         let mut tokenizer = Tokenizer::with_config(config).unwrap();
         let tokens = tokenizer.tokenize_offsets(" ");
@@ -271,9 +321,8 @@ mod tests {
     #[test]
     fn test_boku_ha() {
         let config = TokenizerConfig {
-            dict_path: None,
-            user_dict_path: None,
             mode: Mode::Decompose(Penalty::default()),
+            ..TokenizerConfig::default()
         };
         let mut tokenizer = Tokenizer::with_config(config).unwrap();
         let tokens = tokenizer.tokenize_offsets("僕は");
@@ -441,9 +490,9 @@ mod tests {
     #[test]
     fn test_simple_user_dict() {
         let config = TokenizerConfig {
-            dict_path: None,
             user_dict_path: Some(&Path::new("resources/userdic.csv")),
             mode: Mode::Normal,
+            ..TokenizerConfig::default()
         };
         let mut tokenizer = Tokenizer::with_config(config).unwrap();
         assert!(tokenizer.user_dict.is_some());
@@ -484,9 +533,9 @@ mod tests {
     #[test]
     fn test_detailed_user_dict() {
         let config = TokenizerConfig {
-            dict_path: None,
             user_dict_path: Some(&Path::new("resources/detailed_userdic.csv")),
             mode: Mode::Normal,
+            ..TokenizerConfig::default()
         };
         let mut tokenizer = Tokenizer::with_config(config).unwrap();
         assert!(tokenizer.user_dict.is_some());
@@ -527,9 +576,9 @@ mod tests {
     #[test]
     fn test_mixed_user_dict() {
         let config = TokenizerConfig {
-            dict_path: None,
             user_dict_path: Some(&Path::new("resources/mixed_userdic.csv")),
             mode: Mode::Normal,
+            ..TokenizerConfig::default()
         };
         let mut tokenizer = Tokenizer::with_config(config).unwrap();
         assert!(tokenizer.user_dict.is_some());
@@ -588,9 +637,9 @@ mod tests {
     #[should_panic(expected = "failed to parse word_cost")]
     fn test_user_dict_invalid_word_cost() {
         let config = TokenizerConfig {
-            dict_path: None,
             user_dict_path: Some(&Path::new("test/fixtures/userdic_invalid_word_cost.csv")),
             mode: Mode::Normal,
+            ..TokenizerConfig::default()
         };
         Tokenizer::with_config(config).unwrap();
     }
@@ -599,11 +648,11 @@ mod tests {
     #[should_panic(expected = "user dictionary should be a CSV with 3 or 13 fields")]
     fn test_user_dict_number_of_fields_is_11() {
         let config = TokenizerConfig {
-            dict_path: None,
             user_dict_path: Some(&Path::new(
                 "test/fixtures/userdic_insufficient_number_of_fields.csv",
             )),
             mode: Mode::Normal,
+            ..TokenizerConfig::default()
         };
         Tokenizer::with_config(config).unwrap();
     }
